# Changelog

## v2.2.0 / 2026-01-07

### Features

- Add Python 3.14 support (#59).
- Add Python 3.13 support (#54).

### Fixes

- Add Django as dependency (#62).

### Misc

- Launch pytest from VS Code (#61).
- Update black to 25.12.0 (#60).
- Update flake8 to 7.3.0 (#58).
- Update isort to 7.0.0 (#57).
- Add VS Code settings (#56).
- Add VS Code recommended extensions (#55).
- Improve CONTRIBUTING (#53).
- Add targets setup, venv, installdeps and cleanall (#52).
- Publish to PyPI with OIDC (#51).

## v2.1.0 / 2025-12-22

### Features

- Add Django 5.2 support (#49).
- Add Python 3.12 support (#43).

### Misc

- Add targets clean, lint and test (#48).
- Run linter only on latest Python (#47).
- Refactor requirements (#46).
- Init Makefile (#45).
- Add html report (#44).
- Modernize packaging (#42).
- Update codecov/codecov-action to v5 (#41).
- Update actions/setup-python to v6 (#40).
- Update actions/checkout to v5 (#39).

## v2.0.0 / 2025-12-11

### Backwards Incompatible Changes

- Drop Python 3.6 support (#32).

### Features

- Add Python 3.11 support (#37).
- Add Django 4.2 support (#35).

### Misc

- Fix GitHub Actions badge (#36).
- Simplify tox tests (#34).
- Update codecov/codecov-action to v4 (#33).

## v1.0.0 / 2022-10-18

### Backwards Incompatible Changes

- Drop Python 2.7 support (#22).
- Drop Python 3.5 support (#22).
- Drop Django 1.11 support (#22).

### Features

- Add Python 3.10 support (#28).

### Misc

- Lint via tox (#26).
- Update pytest ecosystem (#24).
- Update flake8 from 3.9.2 to 5.0.4 (#30)
- Update codecov-action from v1 to v3 (#14).
- Update checkout action from v2 to v3 (#19).
- Update setup-python action from v2 to v4 (#20).

## v0.1.0 / 2022-10-12

### Features

- Add Django 3.2 support (#11).

### Misc

- Update Web2018 from 5.2.0 to 6.1.1 (#15).

## v0.0.2 / 2021-07-21

### Features

 - Add online template (#2).

### Improvements

- Add alt attribute for images (#6).

### Fixes

- Fix blue links in GMail (#8).
- Fix typo in logo.inc.html (#7).

### Misc

- Add release workflow to PyPI (#5).
- Update black from 21.5b2 to 21.6b0 (#3).
- Update isort from 5.8.0 to 5.9.2 (#4).

## v0.0.1 / 2021-06-17

- First version, released on an unsuspecting world.
